/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo

import com.kotlindiscord.kord.extensions.ExtensibleBot
import de.limited_dev.botendo.extensions.music.*
import de.limited_dev.botendo.extensions.util.InfoExt
import de.limited_dev.botendo.util.CredentialManager
import de.limited_dev.botendo.util.Logger
import dev.schlaubi.lavakord.LavaKord
import dev.schlaubi.lavakord.kord.lavakord

object Bot {
    //The kord object gets set at app launch
    lateinit var lava: LavaKord
    private lateinit var bot: ExtensibleBot
    suspend fun start() {
        Logger.out("Starting Bot...")

        //Load config
        CredentialManager.load()

        //Don't run the bot when there is no bot token in config
        if (CredentialManager.token == "empty") {
            Logger.out("The config does not contain a bot token")
            return
        }

        //Add Bot token to kord
        //kord = Kord(CredentialManager.token)
        bot = ExtensibleBot(CredentialManager.token) {
            applicationCommands {
                enabled = true
            }

            extensions {
                add(::InfoExt)
                add(::PlayExt)
                add(::StopExt)
                add(::SkipExt)
                add(::NowPlayingExt)
                add(::QueueExt)
            }
        }

        //Add LavaLink
        lava = bot.kordRef.lavakord()

        //Add the LavaLink node from config
        lava.addNode(CredentialManager.linkip, CredentialManager.linkpw)

        //Start the bot
        bot.start()
    }
}
