/*
 *     Botendo
 *     Copyright (C) 2023  limited_dev
 *
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package de.limited_dev.botendo.util

import com.kotlindiscord.kord.extensions.commands.Arguments
import com.kotlindiscord.kord.extensions.commands.application.slash.PublicSlashCommandContext
import com.kotlindiscord.kord.extensions.components.forms.ModalForm
import com.kotlindiscord.kord.extensions.types.respond
import dev.kord.rest.builder.message.EmbedBuilder
import java.time.LocalDateTime
import java.time.format.DateTimeFormatter

object MessageUtil {
    private val dtf: DateTimeFormatter = DateTimeFormatter.ofPattern("dd/MM/yyyy @ HH:mm:ss")

    suspend fun sendEmbedForPublicSlashCommand(
        ctx: PublicSlashCommandContext<Arguments, ModalForm>,
        title: String,
        description: String
    ) {
        ctx.respond {
            embeds.add(
                getEmbed(
                    title,
                    description,
                    ctx.user.asUser().username + "#" + ctx.user.asUser().discriminator
                )
            )
        }
    }

    suspend fun sendEmbedForPublicSlashCommandWithImage(
        ctx: PublicSlashCommandContext<Arguments, ModalForm>,
        title: String,
        description: String,
        thumbnailUrl: String
    ) {
        ctx.respond {
            embeds.add(
                getEmbedWithImage(
                    title,
                    description,
                    ctx.user.asUser().username + "#" + ctx.user.asUser().discriminator,
                    thumbnailUrl
                )
            )
        }
    }

    fun getEmbed(title: String, description: String, source: String): EmbedBuilder {
        val now: LocalDateTime = LocalDateTime.now()
        val ebb = EmbedBuilder()
        ebb.title = title
        ebb.description = description
        ebb.footer = EmbedBuilder.Footer()
        ebb.footer!!.text = ">" + dtf.format(now) + " - $source"
        return ebb
    }

    fun getEmbedWithImage(
        title: String,
        description: String,
        source: String,
        thumbnailUrl: String
    ): EmbedBuilder {
        val ebb = getEmbed(title, description, source)
        ebb.thumbnail = EmbedBuilder.Thumbnail()
        ebb.thumbnail!!.url = thumbnailUrl
        return ebb
    }
}
